@@ -583,7 +583,7 @@ public abstract class KmerSort {
 	public static boolean verbose=true;
 	public static boolean doHashAndSplit=true;
 	public boolean errorState=false;
-	boolean overwrite=false;
+	boolean overwrite=true;
 	boolean append=false;
 	
 }
