@@ -2,7 +2,6 @@ package jgi;
 
 import java.io.File;
 import java.util.ArrayList;
-import java.util.Locale;
 
 import align2.MSA;
 import fileIO.ByteStreamWriter;
@@ -229,7 +228,7 @@ public class FindPrimers_old {
 		
 		t.stop();
 		outstream.println("Time:                         \t"+t);
-		outstream.println("Reads Processed:    "+readsProcessed+" \t"+String.format(Locale.ROOT, "%.2fk reads/sec", (readsProcessed/(double)(t.elapsed))*1000000));
+		outstream.println("Reads Processed:    "+readsProcessed+" \t"+Tools.format("%.2fk reads/sec", (readsProcessed/(double)(t.elapsed))*1000000));
 	}
 	
 
@@ -253,7 +252,7 @@ public class FindPrimers_old {
 		bb.append(query.bases).append('\t');
 		bb.append('*').append('\t');
 		
-		bb.append(String.format(Locale.ROOT, "YI:f:%.2f", (100*f)));
+		bb.append(Tools.format("YI:f:%.2f", (100*f)));
 		
 		return bb;
 	}
